AC_DEFUN([CHECK_FREETYPE],
[
    AC_MSG_CHECKING(for freetype)
    fdirs="/usr/local/freetype /usr/freetype \
            /usr/pkg /usr/local /usr"
    AC_ARG_WITH(freetype,
            AC_HELP_STRING([--with-freetype=DIR], [path to freetype]),
            fdirs="$withval")
    for dir in $fdirs; do
        fdir="$dir"
        if test -f "$dir/lib/libfreetype.so"; then
            found_ft="yes";
            break;
        fi
    done
    if test x_$found_ft != x_yes; then
        AC_MSG_ERROR(cannot find freetype )
    else
	LIBS="-lfreetype $LIBS";
	LDFLAGS="$LDFLAGS -L$fdir/lib -Wl,-R$fdir/lib";
        HAVE_FT=yes
    fi
    AC_SUBST(HAVE_FT)
    AC_MSG_RESULT(yes)
])

AC_DEFUN([CHECK_PNG],
[
    AC_MSG_CHECKING(for libpng)
    pdirs="/usr/local/libpng /usr/local/png /usr/libpng /usr/png \
            /usr/pkg /usr/local /usr"
    AC_ARG_WITH(png,
            AC_HELP_STRING([--with-libpng=DIR], [path to png]),
            pdirs="$withval")
    for dir in $pdirs; do
        pdir="$dir"
        if test -f "$dir/lib/libpng.so"; then
            found_png="yes";
            break;
        fi
    done
    if test x_$found_png != x_yes; then
        AC_MSG_ERROR(cannot find png )
    else
	LIBS="-lpng $LIBS";
	LDFLAGS="$LDFLAGS -L$pdir/lib -Wl,-R$pdir/lib";
        HAVE_PNG=yes
    fi
    AC_SUBST(HAVE_PNG)
    AC_MSG_RESULT(yes)
])

AC_DEFUN([CHECK_JPEG],
[
    AC_MSG_CHECKING(for jpeg)
    jdirs="/usr/local/jpeg /usr/jpeg \
            /usr/pkg /usr/local /usr"
    AC_ARG_WITH(jpeg,
            AC_HELP_STRING([--with-jpeg=DIR], [path to jpeg]),
            jdirs="$withval")
    for dir in $jdirs; do
        jdir="$dir"
        if test -f "$dir/lib/libjpeg.a"; then
            found_jpeg="yes";
            break;
        fi
    done
    if test x_$found_jpeg != x_yes; then
        AC_MSG_ERROR(cannot find jpeg )
    else
	LIBS="-ljpeg $LIBS";
	LDFLAGS="$LDFLAGS -L$jdir/lib";
        HAVE_JPEG=yes
    fi
    AC_SUBST(HAVE_JPEG)
    AC_MSG_RESULT(yes)
])
AC_DEFUN([CHECK_GD],
[
    AC_MSG_CHECKING(for gd)
    gddirs="/usr/local/gd /usr/gd \
            /usr/pkg /usr/local /usr"
    AC_ARG_WITH(gd,
            AC_HELP_STRING([--with-gd=DIR], [path to gd]),
            gddirs="$withval")
    for dir in $gddirs; do
        gddir="$dir"
        if test -f "$dir/include/gd.h"; then
            found_gd="yes";
            CFLAGS="$CFLAGS -I$gddir/include";
            break;
        fi
    done
    if test x_$found_gd != x_yes; then
        AC_MSG_ERROR(cannot find gd )
    else
	LIBS="-lgd $LIBS";
	LDFLAGS="$LDFLAGS -L$gddir/lib -Wl,-R$gddir/lib";
        HAVE_GD=yes
    fi
    AC_SUBST(HAVE_GD)
    AC_MSG_RESULT(yes)
])

AC_DEFUN([CHECK_DB],
[
    AC_MSG_CHECKING(for db)
    dbdirs="/usr/local/db /usr/db \
            /usr/pkg /usr/local /usr"
    AC_ARG_WITH(db,
            AC_HELP_STRING([--with-db=DIR], [path to db]),
            dbdirs="$withval")
    for dir in $dbdirs; do
        dbdir="$dir"
        if test -f "$dir/include/db.h"; then
            found_db="yes";
            CFLAGS="$CFLAGS -I$dbdir/include";
            break;
        fi
    done
    if test x_$found_db != x_yes; then
        AC_MSG_ERROR(cannot find db )
    else
	LIBS="$LIBS -ldb";
	LDFLAGS="$LDFLAGS -L$dbdir/lib -Wl,-R$dbdir/lib";
        HAVE_DB=yes
    fi
    AC_SUBST(HAVE_DB)
    AC_MSG_RESULT(yes)
])

AC_DEFUN([CHECK_APACHE],
[
    AC_MSG_CHECKING(for apache)
    apachedirs="/usr/local/apache /usr/apache \
            /usr/pkg /usr/local /usr /usr/local/httpd"
    AC_ARG_WITH(apache,
            AC_HELP_STRING([--with-apache=DIR], [path to apache]),
            apachedirs="$withval")
    for dir in $apachedirs; do
        apachedir="$dir"
        if test -f "$dir/include/httpd/http_core.h"; then
            found_apache="yes";
            CFLAGS="$CFLAGS -I$apachedir/include/httpd";
            break;
        fi
        if test -f "$dir/include/http_core.h"; then
            found_apache="yes";
            CFLAGS="$CFLAGS -I$apachedir/include";
            break
        fi
        if test -f "$dir/include/apache/http_core.h"; then
            found_apache="yes";
            CFLAGS="$CFLAGS -I$apachedir/include/apache";
            break
        fi
    done
    if test x_$found_apache != x_yes; then
        AC_MSG_ERROR(cannot find apache )
    else
        HAVE_APACHE=yes
    fi
    AC_SUBST(HAVE_APACHE)
    AC_MSG_RESULT(yes)
])

